# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ContractTypeEnum(object):

    """Implementation of the 'contractType' enum.

    TODO: type enum description here.

    Attributes:
        SERVICE: Service contract
        GLOBAL: Global contract
        CUSTOM: Custom contract

    """

    SERVICE = 'service'

    ENUM_GLOBAL = 'global'

    CUSTOM = 'custom'

